# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .available_tool import AvailableTool


class ToolCategory(UniversalBaseModel):
    """
    将可用工具按功能分类
    """

    category: str = pydantic.Field()
    """
    Name of tool category
    """

    tools: typing.List[AvailableTool] = pydantic.Field()
    """
    List of tools under this category
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
